<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xalan="org.apache.xalan.xslt.extensions.Redirect" extension-element-prefixes="xalan">
	<xsl:output method="text" encoding="utf-8"/>
	<xsl:param name="dir" select="'C:\'"/>
	
	<xsl:template match="/">
		<xsl:for-each select="//*[starts-with(name(),'UML')]">
			<xsl:variable name="file" select="concat($dir, @className, '.java')"/>
			<xalan:write file="{$file}">
				<xsl:if test="name()='UMLClassNode'">
					<xsl:apply-templates select="."/>
				</xsl:if>
				<xsl:if test="name()='UMLAbstractClassNode'">
					<xsl:apply-templates select="."/>
				</xsl:if>
				<xsl:if test="name()='UMLInterfaceNode'">
					<xsl:apply-templates select="."/>
				</xsl:if>
			</xalan:write>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="UMLClassNode"><xsl:text>public class </xsl:text><xsl:value-of select="@className"/>
		<xsl:if test="count(child::inheritance/*)>0"><xsl:text> extends</xsl:text><xsl:for-each select="child::inheritance/*">
				<xsl:text> </xsl:text><xsl:value-of select="@className"/>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="count(child::implementation/*)>0"><xsl:text> implements</xsl:text><xsl:for-each select="child::implementation/*">
				<xsl:text> </xsl:text><xsl:value-of select="@className"/>
			</xsl:for-each>
		</xsl:if><xsl:text> { &#10;&#10;</xsl:text>
		<xsl:if test="count(child::composition/*)>0"><xsl:text>&#9;//Compositions&#10;</xsl:text>
		<xsl:for-each select="child::composition/*">
			<xsl:text>&#9;</xsl:text><xsl:value-of select="@className"/><xsl:text>[] </xsl:text><xsl:value-of select="translate(@className, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')"/><xsl:text> = new </xsl:text><xsl:value-of select="@className"/><xsl:text>[</xsl:text><xsl:value-of select="@composition"/><xsl:text>];&#10;</xsl:text>
		</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::Attributes/*)>0"><xsl:text>&#9;//Attributes&#10;</xsl:text>
		<xsl:for-each select="child::Attributes/*">
			<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text>;&#10;</xsl:text>
		</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::Operations/*)>0"><xsl:text>&#9;//Operations&#10;</xsl:text>
			<xsl:for-each select="child::Operations/*">
				<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text> {&#10;</xsl:text>
				<xsl:text>&#9;</xsl:text><xsl:value-of select="./JavaCode"/><xsl:text>&#10;&#9;}&#10;&#10;</xsl:text>
			</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::implementation/*)>0"><xsl:text>&#9;//Implementation&#10;</xsl:text>
			<xsl:for-each select="child::implementation/*">
				<xsl:for-each select="./Operations/*">
					<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text> {}&#10;</xsl:text>
				</xsl:for-each>
			</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
<xsl:text>}</xsl:text>
	</xsl:template>
	
	<xsl:template match="UMLAbstractClassNode">public<xsl:text> </xsl:text>abstract<xsl:text> </xsl:text>class<xsl:text> </xsl:text><xsl:value-of select="@className"/>
		<xsl:if test="count(child::inheritance/*)>0"><xsl:text> extends</xsl:text><xsl:for-each select="child::inheritance/*">
				<xsl:text> </xsl:text><xsl:value-of select="@className"/>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="count(child::implementation/*)>0"><xsl:text> implements</xsl:text><xsl:for-each select="child::implementation/*">
				<xsl:text> </xsl:text><xsl:value-of select="@className"/>
			</xsl:for-each>
		</xsl:if><xsl:text> { &#10;&#10;</xsl:text>
		<xsl:if test="count(child::composition/*)>0"><xsl:text>&#9;//Compositions&#10;</xsl:text>
		<xsl:for-each select="child::composition/*">
			<xsl:text>&#9;</xsl:text><xsl:value-of select="@className"/><xsl:text>[] </xsl:text><xsl:value-of select="translate(@className, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')"/><xsl:text> = new </xsl:text><xsl:value-of select="@className"/><xsl:text>[</xsl:text><xsl:value-of select="@composition"/><xsl:text>];&#10;</xsl:text>
		</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::Attributes/*)>0"><xsl:text>&#9;//Attributes&#10;</xsl:text>
		<xsl:for-each select="child::Attributes/*">
			<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text>;&#10;</xsl:text>
		</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::Operations/*)>0"><xsl:text>&#9;//Operations&#10;</xsl:text>
			<xsl:for-each select="child::Operations/*">
				<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text> {&#10;</xsl:text>
				<xsl:text>&#9;</xsl:text><xsl:value-of select="./JavaCode"/><xsl:text>&#10;&#9;}&#10;&#10;</xsl:text>
			</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::implementation/*)>0"><xsl:text>&#9;//Implementation&#10;</xsl:text>
			<xsl:for-each select="child::implementation/*">
				<xsl:for-each select="./Operations/*">
					<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text> {}&#10;</xsl:text>
				</xsl:for-each>
			</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
<xsl:text>}</xsl:text>
	</xsl:template>
	
	<xsl:template match="UMLInterfaceNode">public<xsl:text> </xsl:text>interface<xsl:text> </xsl:text><xsl:value-of select="@className"/>
		<xsl:if test="count(child::inheritance/*)>0"><xsl:text> extends</xsl:text><xsl:for-each select="child::inheritance/*">
				<xsl:text> </xsl:text><xsl:value-of select="@className"/>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="count(child::implementation/*)>0"><xsl:text> implements</xsl:text><xsl:for-each select="child::implementation/*">
				<xsl:text> </xsl:text><xsl:value-of select="@className"/>
			</xsl:for-each>
		</xsl:if><xsl:text> { &#10;&#10;</xsl:text>
		<xsl:if test="count(child::Attributes/*)>0"><xsl:text>&#9;//Attributes&#10;</xsl:text>
		<xsl:for-each select="child::Attributes/*">
			<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text>;&#10;</xsl:text>
		</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::Operations/*)>0"><xsl:text>&#9;//Operations&#10;</xsl:text>
			<xsl:for-each select="child::Operations/*">
				<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text> {&#10;</xsl:text>
				<xsl:text>&#9;</xsl:text><xsl:value-of select="./JavaCode"/><xsl:text>&#10;&#9;}&#10;&#10;</xsl:text>
			</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="count(child::implementation/*)>0"><xsl:text>&#9;//Implementation&#10;</xsl:text>
			<xsl:for-each select="child::implementation/*">
				<xsl:for-each select="./Operations/*">
					<xsl:text>&#9;</xsl:text><xsl:value-of select="@Visibility"/><xsl:text> </xsl:text><xsl:value-of select="@Return"/><xsl:text> </xsl:text><xsl:value-of select="@Name"/><xsl:text> {}&#10;</xsl:text>
				</xsl:for-each>
			</xsl:for-each><xsl:text>&#10;</xsl:text>
		</xsl:if>
<xsl:text>}</xsl:text>
	</xsl:template>
	
</xsl:stylesheet>